==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggframematerialproperties.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with material properties slides
//

#ifndef IGGFRAMEMATERIALPROPERTIES_H
#define IGGFRAMEMATERIALPROPERTIES_H


#include "iggframe.h"


class iObjectKey;
class iObjectType;

class iggWidgetKeyCheckBox;
class iggWidgetKeyFloatSlider;


class iggFrameMaterialProperties : public iggFrame
{

public:

	iggFrameMaterialProperties(bool withShading, bool withAllInstances, const iObjectType &type, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);

protected:

	virtual void UpdateChildren();

	iggWidgetKeyCheckBox *mShadingBox;
	iggWidgetKeyFloatSlider *mSlider[4];
};

#endif  // IGGFRAMEMATERIALPROPERTIES_H

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/shells/generic/iggframematerialproperties.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame with material properties slides
//

#ifndef IGGFRAMEMATERIALPROPERTIES_H
#define IGGFRAMEMATERIALPROPERTIES_H


#include "iggframe.h"


class iggObjectHandle;


class iggFrameMaterialProperties : public iggFrame
{

public:

	//
	//  Handle to the view subject 
	//
	iggFrameMaterialProperties(const iggObjectHandle *handle, iggFrame *parent);
	virtual ~iggFrameMaterialProperties();

protected:

	iggObjectHandle *mMaterialHandle;
};

#endif  // IGGFRAMEMATERIALPROPERTIES_H
